package com.virtual.plat.server.virtualhost;

import com.virtual.common.AppException;
import com.virtual.plat.server.common.CommonDao;
import com.virtual.plat.server.entity.Domain;
import com.virtual.plat.server.entity.QueryConfig;
import com.virtual.plat.server.entity.QueryResult;
import com.virtual.plat.server.virtualhost.DomainDao;
import com.virtual.plat.server.virtualhost.DomainMgr;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;
import javax.annotation.Resource;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

@Service("domainMgr")
public class DomainMgrImpl implements DomainMgr {

   @Resource
   private DomainDao domainDao = null;
   @Resource
   private CommonDao commonDao = null;


   @Transactional(
      readOnly = true
   )
   public QueryResult queryDomainsByCondition(QueryConfig var1) {
      return this.domainDao.readByCondition(var1);
   }

   @Transactional
   public void addDomain(Domain var1) {
      this.domainDao.insert(var1);
   }

   @Transactional(
      readOnly = true
   )
   public boolean isExistsByForeignId(Long var1, Long var2) {
      QueryConfig var3;
      (var3 = new QueryConfig()).addRestriction("foreignId", var1);
      var3.addRestriction("cloudId", var2);
      QueryResult var4;
      return (var4 = this.domainDao.readByCondition(var3)) != null && var4.getData() != null && var4.getData().size() > 0;
   }

   @Transactional
   public void renameDomain(Domain var1) {
      if(var1.getId() != null) {
         StringBuilder var2;
         (var2 = new StringBuilder("UPDATE TBL_DOMAIN SET TITLE = ")).append("\'" + var1.getTitle() + "\'").append(" WHERE ID = ").append(var1.getId());
         this.domainDao.updateBySql(var2.toString());
      }
   }

   @Transactional
   public void updateDomainStatus(Long var1, Long var2, String var3) {
      this.domainDao.updateDomainStatus((Long)var1, var2, var3);
   }

   @Transactional
   public void syncDomain(List var1, List var2, List var3, long var4) {
      int var6 = 0;
      Iterator var12 = var1.iterator();

      Domain var7;
      while(var12.hasNext()) {
         var7 = (Domain)var12.next();
         String var9 = var7.getUniqueKey();
         if(this.domainDao.readByUniqueKeyAndCloudId(var9, var4) == null) {
            this.domainDao.insert(var7);
            ++var6;
            if(var6 % 20 == 0) {
               this.commonDao.flushAndClear();
            }
         }
      }

      var12 = var2.iterator();

      while(var12.hasNext()) {
         var7 = (Domain)var12.next();
         this.domainDao.update(var7);
         ++var6;
         if(var6 % 20 == 0) {
            this.commonDao.flushAndClear();
         }
      }

      var12 = var3.iterator();

      while(var12.hasNext()) {
         var7 = (Domain)var12.next();
         this.domainDao.delete(var7);
         ++var6;
         if(var6 % 20 == 0) {
            this.commonDao.flushAndClear();
         }
      }

      this.commonDao.flushAndClear();
   }

   private boolean a(long var1, String var3) {
      return this.domainDao.readByUniqueKeyAndCloudId(var3, var1) != null;
   }

   @Transactional
   public void deleteCloudDomain(long var1) {
      this.domainDao.deleteDomainByCloudId(Long.valueOf(var1));
   }

   @Transactional
   public void updateDomain(String var1, String var2) {
      this.domainDao.update(var1, var2);
   }

   @Transactional
   public void updateDomainStatus(String var1, Long var2, String var3) {
      this.domainDao.updateDomainStatus((String)var1, var2, var3);
   }

   @Transactional
   public void deleteDomain(String var1) {
      this.domainDao.deleteDomain(var1);
   }

   @Transactional
   public void updateDomainStatus(String var1, Long var2) {
      this.domainDao.updateDomainStatus(var1, var2.longValue());
   }

   @Transactional
   public Domain queryDomainById(Long var1) {
      Domain var2;
      if((var2 = this.domainDao.readById(var1)) == null) {
         throw new AppException(1001);
      } else {
         return var2;
      }
   }

   @Transactional
   public Domain queryTemplateById(Long var1) {
      Domain var2;
      if((var2 = this.domainDao.readById(var1)) == null) {
         throw new AppException(1000);
      } else {
         return var2;
      }
   }

   @Transactional
   public Domain queryDomainByIdNoException(Long var1) {
      return this.domainDao.readById(var1);
   }

   @Transactional
   public Domain queryDomainByUniqueKeyAndCloudId(String var1, long var2) {
      Domain var4;
      if((var4 = this.domainDao.readByUniqueKeyAndCloudId(var1, var2)) == null) {
         throw new AppException(1001);
      } else {
         return var4;
      }
   }

   @Transactional
   public void updateUserVm(long var1) {
      this.domainDao.updateUserVm(Long.valueOf(var1));
   }

   @Transactional
   public List queryDomainPublicIdList() {
      return this.domainDao.queryDomainPublicIdList();
   }

   @Transactional
   public void delDomainsByUniquekeys(long var1, List var3) {
      this.domainDao.delDomainsByUniquekeys(var1, var3);
   }

   @Transactional
   public List queryDomainsAndTempletsByCloudId(long var1) {
      return this.domainDao.readDomainsAndTempletsByCloudId(var1).getData();
   }

   @Transactional
   public Domain queryDomainByKeyAndCloudIdWithoutException(String var1, long var2) {
      return this.domainDao.readByUniqueKeyAndCloudId(var1, var2);
   }

   @Transactional
   public void updateDomain(Domain var1) {
      this.domainDao.update(var1);
   }

   @Transactional
   public QueryResult queryTemplateByConfig(QueryConfig var1) {
      return this.domainDao.readTemplateByConfig(var1);
   }

   @Transactional
   public List queryTemplatesByCloudId(long var1) {
      QueryResult var3;
      return (List)((var3 = this.domainDao.readTemplatesByCloudId(var1)).getLength() > 0?var3.getData():new ArrayList());
   }

   @Transactional
   public List queryVmIdAndHostNameMapByUniqueKeyList(List var1) {
      return this.domainDao.readVmIdAndHostNameMapByUniqueKeyList(var1);
   }
}
